# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: example2.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='example2.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0e\x65xample2.proto\"5\n\x15\x45xampleReferencedType\x12\r\n\x05key_1\x18\x01 \x01(\t\x12\r\n\x05key_2\x18\x02 \x01(\t*5\n\x15\x45xampleReferencedEnum\x12\x08\n\x04KEY0\x10\x00\x12\x08\n\x04KEY1\x10\x01\x12\x08\n\x04KEY2\x10\x02\x62\x06proto3')
)

_EXAMPLEREFERENCEDENUM = _descriptor.EnumDescriptor(
  name='ExampleReferencedEnum',
  full_name='ExampleReferencedEnum',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KEY0', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY1', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEY2', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=73,
  serialized_end=126,
)
_sym_db.RegisterEnumDescriptor(_EXAMPLEREFERENCEDENUM)

ExampleReferencedEnum = enum_type_wrapper.EnumTypeWrapper(_EXAMPLEREFERENCEDENUM)
KEY0 = 0
KEY1 = 1
KEY2 = 2



_EXAMPLEREFERENCEDTYPE = _descriptor.Descriptor(
  name='ExampleReferencedType',
  full_name='ExampleReferencedType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key_1', full_name='ExampleReferencedType.key_1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key_2', full_name='ExampleReferencedType.key_2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18,
  serialized_end=71,
)

DESCRIPTOR.message_types_by_name['ExampleReferencedType'] = _EXAMPLEREFERENCEDTYPE
DESCRIPTOR.enum_types_by_name['ExampleReferencedEnum'] = _EXAMPLEREFERENCEDENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExampleReferencedType = _reflection.GeneratedProtocolMessageType('ExampleReferencedType', (_message.Message,), {
  'DESCRIPTOR' : _EXAMPLEREFERENCEDTYPE,
  '__module__' : 'example2_pb2'
  # @@protoc_insertion_point(class_scope:ExampleReferencedType)
  })
_sym_db.RegisterMessage(ExampleReferencedType)


# @@protoc_insertion_point(module_scope)
